package com.jiuqi.dna.ide.designer.commands;

import com.jiuqi.dna.ide.designer.DesignerMessages;
import com.jiuqi.dna.ide.designer.elements.ICompositeElement;
import com.jiuqi.dna.ide.designer.elements.IFigureElement;
import org.eclipse.gef.commands.Command;

/* loaded from: com_jiuqi_dna_ide_designer_commands.jar:com/jiuqi/dna/ide/designer/commands/FigureElementChangeConstraintCommand.class */
public class FigureElementChangeConstraintCommand extends Command {
    private IFigureElement element;
    private int x;
    private int y;
    private int oldX;
    private int oldY;
    private int width;
    private int height;
    private int oldWidth;
    private int oldHeight;
    private boolean isMove;
    private boolean isResize;
    private boolean canMove;
    private boolean canResize;

    public FigureElementChangeConstraintCommand(IFigureElement element, int x, int y, int width, int height) {
        if (element == null) {
            throw new NullPointerException("参数element不能为NULL！");
        }
        this.element = element;
        this.x = x;
        this.y = y;
        this.width = width;
        this.height = height;
        getRelativeCoordinate(element.getParent());
        this.oldX = this.element.getX();
        this.oldY = this.element.getY();
        this.oldHeight = element.getHeight();
        this.oldWidth = element.getWidth();
        setLabel(DesignerMessages.FigureElementChangeConstraintCommandLabel);
        this.isMove = (x == this.oldX && y == this.oldY) ? false : true;
        this.isResize = (width == this.oldWidth && height == this.oldHeight) ? false : true;
    }

    private void getRelativeCoordinate(ICompositeElement composite) {
        if (composite == null) {
            return;
        }
        this.x -= composite.getX();
        this.y -= composite.getY();
        getRelativeCoordinate(composite.getParent());
    }

    public boolean canExecute() {
        boolean result;
        this.canMove = this.element.isMovable();
        this.canResize = this.height >= 0 && this.width >= 0 && this.element.isResizable();
        if (this.isMove && this.isResize) {
            result = this.canMove && this.canResize;
        } else if (this.isMove && !this.isResize) {
            result = this.canMove;
        } else if (!this.isMove && this.isResize) {
            result = this.canResize;
        } else {
            result = false;
        }
        return result;
    }

    public void execute() {
        if (this.isMove) {
            this.element.setLocation(this.x, this.y);
        }
        if (this.isResize) {
            this.element.setSize(this.width, this.height);
        }
    }

    public void undo() {
        if (this.isMove) {
            this.element.setLocation(this.oldX, this.oldY);
        }
        if (this.isResize) {
            this.element.setSize(this.oldWidth, this.oldHeight);
        }
    }
}
